@@ -40,6 +40,7 @@ fi
 # for Debian, NAME is "Debian GNU/Linux", shorten this
 debci_distro_name="${debci_distro_name:-$(. /etc/os-release; echo ${NAME% *})}"
 debci_suite=${debci_suite:-unstable}
+debci_suite_list=${debci_suite_list:-${debci_suite}}
 debci_arch=${debci_arch:-$(dpkg --print-architecture)}
 debci_arch_list="${debci_arch_list:-${debci_arch}}"
 # debci-setup-chdist determines the default from debootstrap, don't set one here
@@ -52,7 +53,7 @@ debci_amqp_results_queue=${debci_amqp_results_queue:-"debci_results"}
 debci_swift_url=${debci_swift_url:-}
 debci_sendmail_from="${debci_sendmail_from:-$debci_distro_name Continuous Integration <owner@localhost>}"
 debci_sendmail_to="${debci_sendmail_to:-%s@localhost}"
-debci_url_base="${debci_url_base:-http://localhost:8888}"
+debci_url_base="${debci_url_base:-http://localhost:8080}"
 debci_artifacts_url_base="${debci_artifacts_url_base:-}"
 
 shared_short_options='c:s:a:b:d:hq'
@@ -146,7 +147,7 @@ debci_user=$(stat -c %U "${debci_data_basedir}")
 debci_uid=$(stat -c %u "${debci_data_basedir}")
 debci_group=$(stat -c %G "${debci_data_basedir}")
 
-debci_amqp_queue=${debci_amqp_queue:-"debci-${debci_suite}-${debci_arch}-${debci_backend}"}
+debci_amqp_queue=${debci_amqp_queue:-"debci-${debci_arch}-${debci_backend}"}
 
 debci_lock_dir=${debci_lock_dir:-/var/lock}
 
